@@ -15,23 +15,24 @@ func CloseCmd() *cobra.Command {
 		Long:    "Close pull requests with a specified branch name in an organization and with specified conditions.",
 		Args:    cobra.NoArgs,
 		PreRunE: logFlagInit,
-		RunE:    close,
+		RunE:    closeCMD,
 	}
 
 	cmd.Flags().StringP("branch", "B", "multi-gitter-branch", "The name of the branch where changes are committed.")
 	configurePlatform(cmd)
+	configureRunPlatform(cmd, false)
 	configureLogging(cmd, "-")
 	configureConfig(cmd)
 
 	return cmd
 }
 
-func close(cmd *cobra.Command, args []string) error {
+func closeCMD(cmd *cobra.Command, _ []string) error {
 	flag := cmd.Flags()
 
 	branchName, _ := flag.GetString("branch")
 
-	vc, err := getVersionController(flag, true)
+	vc, err := getVersionController(flag, true, false)
 	if err != nil {
 		return err
 	}
